@@ -298,9 +298,15 @@ typedef struct {
 
 static apollonianstruct *apollonians = (apollonianstruct *) NULL;
 
+#ifdef WIN32
+#define FONT_HEIGHT 15
+#define FONT_WIDTH 10
+#define FONT_LENGTH 16
+#else
 #define FONT_HEIGHT 19
 #define FONT_WIDTH 15
 #define FONT_LENGTH 20
+#endif
 #define MAX_CHAR 10
 #define K       2.15470053837925152902  /* 1+2/sqrt(3) */
 #define MAXBEND 100 /* Do not want configurable by user since it will take too
@@ -545,7 +551,7 @@ p(ModeInfo *mi, circle c)
 		  XDrawString(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
 			((int) (cp->size * c.x / (2.0 * c.e) + cp->offset.x)),
 			((int) (cp->size * c.y / (2.0 * c.e) + MI_HEIGHT(mi) -
-			FONT_HEIGHT / 2)), space_string[(int) cp->geometry],
+			FONT_HEIGHT / 2)), (char *) space_string[(int) cp->geometry],
 			strlen(space_string[(int) cp->geometry]));
 		}
 		return;
