@@ -154,6 +154,7 @@ typedef struct _TPoint {
 
 /* ---------------------------------------------------------------------- */
 
+#ifndef WIN32
 /* aliases for vars defined in the bitmap file */
 #define FLY_WIDTH		image_width
 #define FLY_HEIGHT		image_height
@@ -166,6 +167,7 @@ typedef struct _TPoint {
 #define FLY2_HEIGHT  image2_height
 #define FLY2_BITS    image2_bits
 #endif
+#endif
 
 typedef struct {		/* info about a "fly" */
 	int         x, y;
@@ -476,15 +478,18 @@ init_fly(ModeInfo * mi, Fly * f)
 	(void) memset((char *) f, 0, sizeof (Fly));	/* clear everything to zero */
 
 	f->side = FLY_SIDE_LEFT;
-
-	if (MI_IS_ICONIC(mi)) {
-		/* image is just a dot when iconic */
-		f->width = f->height = FLY_ICON_SIZE;
-		f->vx = NRAND(4) + 1;	/* slower when iconic */
-	} else {
+#ifndef WIN32
+	if (!MI_IS_ICONIC(mi))
+	{
 		f->width = ep->flywidth;
 		f->height = ep->flyheight;
 		f->vx = NRAND(15) + 1;	/* random horiz velocity */
+	} else
+#endif
+	{
+		/* image is just a dot when iconic */
+		f->width = f->height = FLY_ICON_SIZE;
+		f->vx = NRAND(4) + 1;	/* slower when iconic */
 	}
 
 	f->y = NRAND(win_height);
@@ -764,7 +769,7 @@ create_eyes(ModeInfo * mi, Eyes * e, Eyes * eyes, int num_eyes)
 
 	/* clear the offscreen pixmap to background color */
 	XSetForeground(display, ep->eyeGC, black_pixel);
-	XFillRectangle(display, e->pixmap, ep->eyeGC, 0, 0, e->width, e->height);
+	XFillRectangle(display, (Drawable) e->pixmap, ep->eyeGC, 0, 0, e->width, e->height);
 
 	/* make the full eye images in the offscreen Pixmap */
 	make_eye(mi, e->pixmap, e, 0, True);
@@ -932,6 +937,7 @@ init_eyes(ModeInfo * mi)
 	}
 	ep = &eye_info[MI_SCREEN(mi)];
 
+#ifndef WIN32
 	if (ep->flypix == None) {
 		getPixmap(mi, window, FLY_WIDTH, FLY_HEIGHT, FLY_BITS,
 			  &(ep->flywidth), &(ep->flyheight), &(ep->flypix),
@@ -954,6 +960,8 @@ init_eyes(ModeInfo * mi)
 		}
 #endif
 	}
+#else
+#endif
 	if (ep->flyGC == None) {
 		XGCValues   gcv;
 
