@@ -1868,7 +1868,7 @@ show_ball(ModeInfo *mi, unsigned long color, Trace *s)
   if(s->y*sp->scale >  MI_HEIGHT(mi) * 2) return;
 
   XSetForeground(MI_DISPLAY(mi), MI_GC(mi), color);
-  if (s->divisions == 0 || color == MI_BLACK_PIXEL(mi))  {
+  if (s->divisions == 0)  {
 	XFillArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
 			 x - BALLRADIUS, y - BALLRADIUS,
 			 2*BALLRADIUS, 2*BALLRADIUS,
@@ -1882,8 +1882,8 @@ show_ball(ModeInfo *mi, unsigned long color, Trace *s)
 			 x - BALLRADIUS, y - BALLRADIUS,
 			 2*BALLRADIUS, 2*BALLRADIUS,
 			 (offset + 11520) % 23040, 5760);
-
-	XSetForeground(MI_DISPLAY(mi), MI_GC(mi), MI_WHITE_PIXEL(mi));
+	if (color != MI_BLACK_PIXEL(mi))
+		XSetForeground(MI_DISPLAY(mi), MI_GC(mi), MI_WHITE_PIXEL(mi));
 	XFillArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
 			 x - BALLRADIUS, y - BALLRADIUS,
 			 2*BALLRADIUS, 2*BALLRADIUS,
@@ -1897,8 +1897,8 @@ show_ball(ModeInfo *mi, unsigned long color, Trace *s)
 			 x - BALLRADIUS, y - BALLRADIUS,
 			 2*BALLRADIUS, 2*BALLRADIUS,
 			 offset % 23040, 11520);
-
-	XSetForeground(MI_DISPLAY(mi), MI_GC(mi), MI_WHITE_PIXEL(mi));
+	if (color != MI_BLACK_PIXEL(mi))
+		XSetForeground(MI_DISPLAY(mi), MI_GC(mi), MI_WHITE_PIXEL(mi));
 	XFillArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
 			 x - BALLRADIUS, y - BALLRADIUS,
 			 2*BALLRADIUS, 2*BALLRADIUS,
@@ -2626,7 +2626,7 @@ init_juggle(ModeInfo * mi)
   sp->scale = MIN(MI_HEIGHT(mi)/480.0, MI_WIDTH(mi)/160.0);
 
   if(describe && mode_font == None) { /* Check to see if there's room to describe patterns. */
-	mode_font = XQueryFont(MI_DISPLAY(mi), XGContextFromGC(MI_GC(mi)));
+	mode_font = (XFontStruct *) XQueryFont(MI_DISPLAY(mi), XGContextFromGC(MI_GC(mi)));
   }
 }
 
@@ -2647,11 +2647,14 @@ draw_juggle(ModeInfo * mi)
   MI_IS_DRAWN(mi) = True;
 
   /* Update timer */
+#ifndef WIN32
   if (real) {
 	struct timeval tv;
 	(void)gettimeofday(&tv, NULL);
 	sp->time = (int) ((tv.tv_sec - sp->begintime)*1000 + tv.tv_usec/1000);
-  } else {
+  } else
+#endif
+  {
 	sp->time += MI_DELAY(mi) / 1000;
   }
 
