@@ -102,12 +102,11 @@ ModStruct   matrix_description =
  "Shows the Matrix", 0, NULL};
 #endif
 
+#ifdef MODE_matrix
 #ifndef VMS
 #include <X11/Intrinsic.h>
 #endif
 
-#ifdef MODE_matrix
-
 /*
  * state associated with a single column of the waterfall display
  */
@@ -396,8 +395,8 @@ static void new_column(const ModeInfo *mi, column_t *c)
    * clear the pixmap to get rid of previous data or initialize
    */
   XSetForeground(MI_DISPLAY(mi), MI_GC(mi), mp->bg);
-  XFillRectangle(MI_DISPLAY(mi), c->pixmap, MI_GC(mi),
-				 0, 0, PIXMAP_WIDTH, mp->pixmapHeight);
+  XFillRectangle(MI_DISPLAY(mi), (Drawable) c->pixmap, MI_GC(mi),
+	 0, 0, PIXMAP_WIDTH, mp->pixmapHeight);
 
   /*
    * Write characters into the column pixmap, starting at the
@@ -440,10 +439,11 @@ static void new_column(const ModeInfo *mi, column_t *c)
 			  kOffset = MATRIX_RANDOM(0, katakana_num_cells);
 			}
 
-		  XCopyArea(MI_DISPLAY(mi), src, c->pixmap, MI_GC(mi),
-					kOffset * katakana_cell_width, 0,
-					katakana_cell_width, katakana_cell_height,
-					0, currChar * katakana_cell_height);
+		  XCopyArea(MI_DISPLAY(mi), (Drawable) src,
+			(Drawable) c->pixmap, MI_GC(mi),
+			kOffset * katakana_cell_width, 0,
+			katakana_cell_width, katakana_cell_height,
+			0, currChar * katakana_cell_height);
 
 		  c->strLen--;
 		}
@@ -661,11 +661,11 @@ void draw_matrix(ModeInfo *mi)
 	  if (c->yPtr <= 0) /* we're about to finish the current pixmap */
 		{
 		  /* exhaust the pixels in the current pixmap */
-		  XCopyArea(MI_DISPLAY(mi), c->pixmap,
-					MI_WINDOW(mi), MI_GC(mi),
-					0, 0,
-					PIXMAP_WIDTH, yDelta + c->yPtr,
-					xOffset, -(c->yPtr));
+		  XCopyArea(MI_DISPLAY(mi), (Drawable) c->pixmap,
+			MI_WINDOW(mi), MI_GC(mi),
+			0, 0,
+			PIXMAP_WIDTH, yDelta + c->yPtr,
+			xOffset, -(c->yPtr));
 
 #ifdef RANDOMIZE_COLUMNS
 		  /* regenerate the column pixmap with new text */
@@ -678,22 +678,22 @@ void draw_matrix(ModeInfo *mi)
 #endif
 
 		  /* fill in the remainder of the column from the new pixmap */
-		  XCopyArea(MI_DISPLAY(mi), c->pixmap,
-					MI_WINDOW(mi), MI_GC(mi),
-					0, mp->pixmapHeight + c->yPtr,
-					PIXMAP_WIDTH, -(c->yPtr),
-					xOffset, 0);
+		  XCopyArea(MI_DISPLAY(mi), (Drawable) c->pixmap,
+			MI_WINDOW(mi), MI_GC(mi),
+			0, mp->pixmapHeight + c->yPtr,
+			PIXMAP_WIDTH, -(c->yPtr),
+			xOffset, 0);
 
 		  c->yPtr += mp->pixmapHeight;
 		}
 	  else
 		{
 		  /* fill in the remainder of the column from the pixmap */
-		  XCopyArea(MI_DISPLAY(mi), c->pixmap,
-					MI_WINDOW(mi), MI_GC(mi),
-					0, c->yPtr,
-					PIXMAP_WIDTH, yDelta,
-					xOffset, 0);
+		  XCopyArea(MI_DISPLAY(mi), (Drawable) c->pixmap,
+			MI_WINDOW(mi), MI_GC(mi),
+			0, c->yPtr,
+			PIXMAP_WIDTH, yDelta,
+			xOffset, 0);
 		}
 	}
 }
