@@ -94,7 +94,7 @@ static const char sccsid[] = "@(#)petri.c	5.04 2002/07/19 xlockmore";
 #include <math.h>
 
 #define FLOAT float
-#define RAND_FLOAT (((FLOAT) (random() & 0xffff)) / ((FLOAT) 0x10000))
+#define RAND_FLOAT (((FLOAT) (LRAND() & 0xffff)) / ((FLOAT) 0x10000))
 
 #define DEF_MEMTHROTTLE "22M"
 #define DEF_DIAGLIM "1.414"
@@ -913,13 +913,13 @@ static int randblip (ModeInfo * mi , int doit)
     }
     else
     {
-	n = random () % 3 + 3;
+	n = NRAND(3) + 3;
     }
 
     while (n--)
     {
-	int x = random () % sp->arr_width;
-	int y = random () % sp->arr_height;
+	int x = NRAND(sp->arr_width);
+	int y = NRAND(sp->arr_height);
 	int c;
 	FLOAT s;
 	if (b)
@@ -932,7 +932,7 @@ static int randblip (ModeInfo * mi , int doit)
 	    if ( sp->count <= 1 )
 	      c = 1;
 	    else
-	      c = (random () % (sp->count-1)) + 1;
+	      c = (NRAND(sp->count-1)) + 1;
 	    s = RAND_FLOAT * (sp->maxlifespeed - sp->minlifespeed) + sp->minlifespeed;
 	}
 	newcell (mi , &sp->arr[y * sp->arr_width + x], c, s);
