@@ -88,8 +88,15 @@ hsb2rgb(double H, double S, double B,
  * Output is that many rgb triples which describe a linear
  * interpolate ramp between the two input colors.
  */
-
+#ifndef WIN32
 static void
+#else
+/*-
+ * make sure this function is NOT static under WIN32. We use it to
+ * create the colortable in WIN32 specific stuff in xlock.c
+ */
+void
+#endif
 hsbramp(double h1, double s1, double b1, double h2, double s2, double b2,
     int count, unsigned char *red, unsigned char *green, unsigned char *blue)
 {
@@ -110,7 +117,7 @@ hsbramp(double h1, double s1, double b1, double h2, double s2, double b2,
 /* Formerly in xlock.c */
 
 unsigned long
-allocPixel(Display * display, Colormap cmap, const char *name, const char *def)
+allocPixel(Display * display, Colormap cmap, char *name, char *def)
 {
 	XColor      col, tmp;
 
