@@ -13,7 +13,7 @@
  */
 
 extern unsigned long allocPixel(Display * display, Colormap cmap,
-				const char *name, const char *def);
+				char *name, char *def);
 
 extern void setColormap(Display * display, Window window, Colormap map,
 			Bool inwindow);
