@@ -39,8 +39,11 @@ char       *messagefontname;
 #include "magick.h"
 #endif
 
-
+#ifndef WIN32
 #include <X11/Xutil.h>
+#else
+#include "Xapi.h"
+#endif
 #include <sys/stat.h>
 #include <stdio.h>
 
