@@ -258,7 +258,7 @@ LockStruct  LockProcs[] =
 #ifdef MODE_flow
 	{(char *) "flow", init_flow, draw_flow, release_flow,
 	 refresh_flow, init_flow, (ModeHook *) NULL, &flow_opts,
-	 1000, 1024, 3000, -10, 64, 1.0, (char *) "",
+	 1000, 1024, 10000, -10, 64, 1.0, (char *) "",
 	 (char *) "Shows dynamic strange attractors", 0, NULL},
 #endif
 #ifdef MODE_forest
@@ -802,10 +802,12 @@ LockStruct  LockProcs[] =
 #endif
 
 /* SPECIAL MODES */
+#ifndef WIN32
 	{(char *) "blank", init_blank, draw_blank, release_blank,
 	 refresh_blank, init_blank, (ModeHook *) NULL, &blank_opts,
 	 3000000, 1, 1, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows nothing but a black screen", 0, NULL},
+#endif /* !WIN32 */
 #ifdef MODE_run
 	{(char *) "run", init_run, draw_run, release_run,
 	 refresh_run, init_run, (ModeHook *) NULL, &run_opts,
@@ -822,10 +824,12 @@ LockStruct  LockProcs[] =
 	 1, 1, 1, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows a random mode (except blank and bomb)", 0, NULL},
 #else
+#ifndef WIN32
 	{(char *) "random", init_random, draw_random, release_random,
 	 refresh_random, change_random, (ModeHook *) NULL, &random_opts,
 	 1, 1, 1, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows a random mode (except blank)", 0, NULL},
+#endif /* !WIN32 */
 #endif
 };
 
