@@ -544,17 +544,24 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_ant3d
 #define MODE_apollonian
 #define MODE_ball
+#ifndef WIN32
 #define MODE_bat
+#endif /* !WIN32 */
 #define MODE_blot
 #define MODE_bouboule
+#ifndef WIN32
 #define MODE_bounce
+#endif /* !WIN32 */
 #define MODE_braid
+#ifndef WIN32
 #define MODE_bubble
+#endif /* !WIN32 */
 #define MODE_bug
 #define MODE_clock
 #define MODE_coral
 #define MODE_crystal
 #define MODE_daisy
+#ifndef WIN32
 #define MODE_dclock
 /*-
  * Comment out dclock sub-modes to disable them from random selection.
@@ -564,33 +571,46 @@ extern void release_last_mode(ModeInfo *);
 /* #define MODE_dclock_y2k */
 /* #define MODE_dclock_millennium */
 #define MODE_decay
+#endif /* !WIN32 */
 #define MODE_deco
 #define MODE_demon
+#ifndef WIN32
 #define MODE_dilemma
+#endif /* !WIN32 */
 #define MODE_discrete
 #define MODE_dragon
 #define MODE_drift
 #define MODE_euler2d
+#ifndef WIN32
 #define MODE_eyes
+#endif /* !WIN32 */
 #define MODE_fadeplot
 #define MODE_fiberlamp
+#ifndef WIN32
 #define MODE_flag
+#endif /* !WIN32 */
 #define MODE_flame
 #define MODE_flow
 #define MODE_forest
 #define MODE_galaxy
+#ifndef WIN32
 #define MODE_goop
+#endif /* !WIN32 */
 #define MODE_grav
 #define MODE_helix
 #define MODE_hop
 #define MODE_hyper
 #define MODE_ico
+#ifndef WIN32
 #define MODE_ifs
 #define MODE_image
+#endif /* !WIN32 */
 #define MODE_juggle
 #define MODE_julia
 #define MODE_kaleid
+#ifndef WIN32
 #define MODE_kumppa
+#endif /* !WIN32 */
 #define MODE_laser
 #define MODE_life
 #define MODE_life1d
@@ -601,36 +621,50 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_loop
 #define MODE_lyapunov
 #define MODE_mandelbrot
+#ifndef WIN32
 #define MODE_marquee
 #define MODE_matrix
+#endif /* !WIN32 */
 #define MODE_maze
 #define MODE_mountain
 #define MODE_munch
+#ifndef WIN32
 #define MODE_nose
 #define MODE_pacman
 #define MODE_penrose
+#endif /* !WIN32 */
 #define MODE_petal
 #define MODE_petri
 #define MODE_polyominoes
+#ifndef WIN32
 #define MODE_puzzle
+#endif /* !WIN32 */
 #define MODE_pyro
 #define MODE_qix
 #define MODE_roll
 #define MODE_rotor
 #define MODE_scooter /* should be combined with star some day */
+#ifndef WIN32
 #define MODE_shape
+#endif /* !WIN32 */
 #define MODE_sierpinski
+#ifndef WIN32
 #define MODE_slip
+#endif /* !WIN32 */
 #define MODE_space /* should be combined with star some day */
 #define MODE_sphere
 #define MODE_spiral
 #define MODE_spline
+#ifndef WIN32
 #define MODE_star
 #define MODE_starfish
 #define MODE_strange
+#endif /* !WIN32 */
 #define MODE_swarm
+#ifndef WIN32
 #define MODE_swirl
 #define MODE_t3d
+#endif /* !WIN32 */
 #define MODE_tetris
 #define MODE_thornbird
 #define MODE_tik_tak
@@ -640,11 +674,17 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_turtle
 #define MODE_vines
 #define MODE_voters
+#ifndef WIN32
 #define MODE_wator
+#endif /* !WIN32 */
 #define MODE_wire
+#ifndef WIN32
 #define MODE_world
+#endif /* !WIN32 */
 #define MODE_worm
+#ifndef WIN32
 #define MODE_xcl
+#endif /* !WIN32 */
 #define MODE_xjack
 
 #ifdef USE_BOMB
