@@ -680,14 +680,14 @@ gpasskey(char *pass)
 {
 	static char saltchars[CPASSCHARS + 1] =
 	"abcdefghijklmnopwrstuvwxyzABCDEFGHIJKLMNOPWRSTUVWXYZ1234567890./";
-	char        pw[9], salt[3], *pw2;
+	char        *pw, *pw2, salt[3];
 #if 0
 	char       *getpass(const char *);
 #endif
 
-	(void) strncpy(pw, (char *) getpass("Key: "), sizeof (pw));
-	pw2 = (char *) getpass("Again:");
-	if (strcmp(pw, pw2) != 0) {
+	pw = (char *) getpass("  Key: ");
+	pw2 = (char *) getpass("Again: ");
+	if (strncmp(pw, pw2, 8) != 0) {
 		(void) fprintf(stderr, "%s: Mismatch, try again\n", ProgramName);
 		exit(1);
 	}
@@ -1219,8 +1219,9 @@ checkPasswd(char *buffer)
 	(void) seteuid(ruid); /* back to user's privileges */
 #endif
 
-#ifndef GENTOO
-	/* https://bugs.gentoo.org/show_bug.cgi?id=96212 */
+/* Seems to cause problems on several systems including GenToo if defined */
+/* https://bugs.gentoo.org/show_bug.cgi?id=96212 */
+#ifdef GOOD_PAM
 	pam_error = pam_acct_mgmt(pamh, 0);
 #endif
 	if (pam_error == PAM_NEW_AUTHTOK_REQD)
