@@ -1494,6 +1494,7 @@ extern int  gethostname(char *, size_t);
 static void
 checkDisplay(void)
 {
+#ifndef WIN32
 	char       *buf;
 	struct hostent *host;
 
@@ -1610,6 +1611,7 @@ checkDisplay(void)
 #ifdef VMS
 	}
 #endif
+#endif /* !WIN32 */
 }
 
 static void
