@@ -111,7 +111,9 @@ ERROR ! Define PROGCLASS, HACK_INIT, and HACK_DRAW before including xlockmore.h
 #define ABS(a)((a)<0 ? -(a) : (a))
 
 /* Maximum possible number of colors (*not* default number of colors.) */
+#ifndef WIN32
 #define NUMCOLORS 256
+#endif /* !WIN32 */
 
 /* The globals that screenhack.c expects (initialized by xlockmore.c).
  */
@@ -138,6 +140,14 @@ XrmOptionDescRec options[100];
 #endif
 #else /* HAVE_CONFIG_H */
 
+#ifdef WIN32
+#define HAVE_FCNTL_H 1
+#define HAVE_LIMITS_H 1
+#define HAVE_SYSLOG_H 1
+#define HAVE_MEMORY_H 1
+#define HAVE_STRDUP 1
+#else /* !WIN32 */
+
 /* THIS MAY SOON BE DEFUNCT, SHOULD WORK NOW THOUGH FOR IMAKE */
 #define HAVE_GLBINDTEXTURE 1
 #if !defined(__cplusplus) && !defined(c_plusplus)
@@ -190,14 +200,17 @@ XrmOptionDescRec options[100];
 #define HAVE_STRDUP 1
 #endif /* !ultrix */
 #endif /* !VMS */
+#endif /* !WIN32 */
 #endif /* !HAVE_CONF_H */
 
 #include <sys/types.h>
+#ifndef WIN32
 #ifdef __NetBSD__
 #include <signal.h>
 #else /* !__NetBSD__ */
 #include <sys/signal.h>
 #endif /* __NetBSD__ */
+#endif /* !WIN32 */
 #if defined( VMS ) && defined( __cplusplus )
 /* Xlib.h for VMS is not (yet) compatible with C++ *
  * The resulting warnings are switched off here    */
@@ -206,10 +219,17 @@ XrmOptionDescRec options[100];
 #ifdef VMS
 #include "vms_x_fix.h"
 #endif
+#ifndef WIN32
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xos.h>
 #include <X11/Xresource.h>
+#else
+#include "Xapi.h"
+/* wingdi.h also defines NUMCOLORS but to 24 */
+#undef NUMCOLORS
+#define NUMCOLORS 256
+#endif /* WIN32 */
 #if defined( VMS ) && defined( __cplusplus )
 #pragma message enable nosimpint
 #endif
@@ -360,7 +380,9 @@ struct hostent {
 #endif
 
 #else
+#ifndef WIN32
 #include <netdb.h>		/* Gives problems on Solaris 2.6 with gcc */
+#endif /* !WIN32 */
 #endif
 #include <ctype.h>
 #if HAVE_DIRENT_H
@@ -576,4 +598,9 @@ XFillRectangle(d,w,g,xl,yl,xs,ys)
 
 #include "random.h"
 
+#ifdef WIN32
+void xlockmore_win32_text(int xloc, int yloc, char *text);
+void xlockmore_set_debug(char *text);
+#endif
+
 #endif /* __XLOCK_XLOCK_H__ */
